netapp_ontap.models.aggregate_block_storage API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.aggregate_block_storage`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AggregateBlockStorageSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AggregateBlockStorage object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `hybrid_cache: AggregateBlockStorageHybridCache GET`

    Contains the configuration for the hybrid cache. The hybrid cache is made up of either whole SSDs or storage pool SSDs.

  `mirror: AggregateBlockStorageMirror GET POST PATCH`

    The mirror field of the aggregate_block_storage.

  `plexes: List[Plex] GET`

    Plex reference for each plex in the aggregate.

  `primary: AggregateBlockStoragePrimary GET POST PATCH`

    Configuration information for the primary storage portion of the aggregate. This excludes the hybrid cache details.

  `storage_type: str GET`

    Type of aggregate.

    Valid choices:

    - hdd
    - hybrid
    - lun
    - ssd
    - vmdisk
  `uses_partitions: bool GET`

    If true, aggregate is using shared disks.